==> bambootracker_0.5.1.orig.tar.gz: BambooTracker-0.5.1/BambooTracker/gui/transpose_song_dialog.hpp <==
/*
 * Copyright (C) 2020 Rerrah
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef TRANSPOSE_SONG_DIALOG_HPP
#define TRANSPOSE_SONG_DIALOG_HPP

#include <vector>
#include <QDialog>
#include <QListWidgetItem>

namespace Ui {
	class TransposeSongDialog;
}

class TransposeSongDialog : public QDialog
{
	Q_OBJECT

public:
	explicit TransposeSongDialog(QWidget *parent = nullptr);
	~TransposeSongDialog() override;

	int getTransposeSeminotes() const;
	std::vector<int> getExcludeInstruments() const;

private:
	Ui::TransposeSongDialog *ui;
	QListWidgetItem* checks[128];
};

#endif // TRANSPOSE_SONG_DIALOG_HPP

==> bambootracker_0.6.4.orig.tar.gz: BambooTracker-0.6.4/BambooTracker/gui/transpose_song_dialog.hpp <==
/*
 * Copyright (C) 2020 Rerrah
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef TRANSPOSE_SONG_DIALOG_HPP
#define TRANSPOSE_SONG_DIALOG_HPP

#include <vector>
#include <QDialog>
#include <QListWidgetItem>

namespace Ui {
	class TransposeSongDialog;
}

class TransposeSongDialog : public QDialog
{
	Q_OBJECT

public:
	explicit TransposeSongDialog(QWidget *parent = nullptr);
	~TransposeSongDialog() override;

	int getTransposeSemitones() const;
	std::vector<int> getExcludeInstruments() const;

private:
	Ui::TransposeSongDialog *ui;
	QListWidgetItem* checks[128];
};

#endif // TRANSPOSE_SONG_DIALOG_HPP
